import os
import logging
import time
from functools import wraps


class DecoLogger:
    def __init__(self, path):
        folder = path.rsplit(os.sep, 1)[0]
        os.makedirs(folder, exist_ok=True)
        self.app_logger = logging.getLogger("app")
        self.app_logger.setLevel(logging.INFO)
        self.app_handler = logging.FileHandler(path, mode="a")
        self.app_handler.setFormatter(
            logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
        )
        self.app_logger.addHandler(self.app_handler)

    def return_logging(self, func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            result = func(*args, **kwargs)
            self.app_logger.info(f"함수 '{func.__name__}' 리턴값: {result}")
            return result

        return wrapper

    def time_logging(self, func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            start_time = time.time()
            result = func(*args, **kwargs)
            end_time = time.time()
            execution_time = end_time - start_time
            self.app_logger.info(f"함수 '{func.__name__}' 실행시간: {execution_time}")
            return result

        return wrapper

    def error_logging(self, func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            try:
                result = func(*args, **kwargs)  # 함수 실행
            except Exception as e:
                result = str(e)
            self.app_logger.info(f"함수 '{func.__name__}' 리턴값: {result}")
            return result

        return wrapper



from setuptools import setup, find_packages

with open("README.md", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="DecoLogger",
    long_description=long_description,
    long_description_content_type="text/markdown",
    version="0.0.5",
    description="It is the DecoLogger",
    author="chogamy",
    author_email="gamy0315@gmail.com",
    url="https://github.com/chogamy/DecoLogger",
    install_requires=[],
    packages=find_packages(exclude=[]),
    keywords=["logger", "decorator", "time", "error"],
    python_requires=">=3.6",
    package_data={},
    zip_safe=False,
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
)
